@@ -75,8 +75,6 @@ struct ast_geoloc_profile {
 	AST_DECLARE_STRING_FIELDS(
 		AST_STRING_FIELD(location_reference);
 		AST_STRING_FIELD(notes);
-		AST_STRING_FIELD(method);
-		AST_STRING_FIELD(location_source);
 	);
 	enum ast_geoloc_pidf_element pidf_element;
 	enum ast_geoloc_precedence precedence;
@@ -84,10 +82,6 @@ struct ast_geoloc_profile {
 	struct ast_variable *location_refinement;
 	struct ast_variable *location_variables;
 	struct ast_variable *usage_rules;
-	int suppress_empty_ca_elements;
-	enum ast_geoloc_format format;
-	struct ast_variable *location_info;
-	struct ast_variable *confidence;
 };
 
 struct ast_geoloc_eprofile {
@@ -108,7 +102,6 @@ struct ast_geoloc_eprofile {
 	struct ast_variable *effective_location;
 	struct ast_variable *usage_rules;
 	struct ast_variable *confidence;
-	int suppress_empty_ca_elements;
 };
 
 /*!
@@ -165,7 +158,7 @@ const char *ast_geoloc_validate_result_to_str(enum ast_geoloc_validate_result re
  * \brief Validate that the names of the variables in the list are valid codes or synonyms
  *
  * \param varlist Variable list to check.
- * \param[out] result Pointer to char * to receive failing item.
+ * \param result[OUT] Pointer to char * to receive failing item.
  *
  * \return result code.
  */
@@ -176,7 +169,7 @@ enum ast_geoloc_validate_result ast_geoloc_civicaddr_validate_varlist(
  * \brief Validate that the variables in the list represent a valid GML shape
  *
  * \param varlist Variable list to check.
- * \param[out] result Pointer to char * to receive failing item.
+ * \param result[OUT] Pointer to char * to receive failing item.
  *
  * \return result code.
  */
@@ -317,15 +310,6 @@ struct ast_datastore *ast_geoloc_datastore_find(struct ast_channel *chan);
  */
 struct ast_geoloc_eprofile *ast_geoloc_eprofile_alloc(const char *name);
 
-/*!
- * \brief Duplicate an effective profile.
- *
- * \param src The eprofile to duplicate.
- *
- * \return The duplicated effective profile ao2 object.
- */
-struct ast_geoloc_eprofile *ast_geoloc_eprofile_dup(struct ast_geoloc_eprofile *src);
-
 /*!
  * \brief Allocate a new effective profile from an existing profile.
  *
